/*
 * Project name:
     PortExpander (Demonstration of the Port Expander library routines)
 * Copyright:
     (c) Mikroelektronika, 2009.
 * Revision History:
     20080930:
       - initial release;
       - 20090818 - Slavisa Zlatanovic;
 * Description:
     This project is simple demonstration how to use Port Expander Library functions.
 * Test configuration:
     MCU:             ATmega16
                      http://www.atmel.com/dyn/resources/prod_documents/doc2466.pdf
     Dev.Board:       EasyAVR6
                      http://www.mikroe.com/en/tools/easyavr6/
     Oscillator:      External Clock 8.0000 MHz
     Ext. Modules:    -
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/en/compilers/mikroc/avr/
 * NOTES:
     - Turn on switches SW9.7, SW9.8, SW6.1, SW6.5, SW6.7 SW7.1 and SW7.5.
     - Turn on PORT0 and PORT1 LEDs (SW10.8).
     - Turn on PORTA LEDs (SW8.1).
 */

// Port Expander module connections
sbit  SPExpanderCS  at PORTB1_bit;
sbit  SPExpanderRST at PORTB2_bit;
sbit  SPExpanderCS_Direction  at DDB1_bit;
sbit  SPExpanderRST_Direction at DDB2_bit;
// End Port Expander module connections

unsigned char i = 0;

// comment / uncomment the apropriate line to
// get output on the wanted port PO or P1

#define Output_PORT0
//#define Output_PORT1

void main() {
  DDRA = 0xFF;                           // Set PORTA as output
  #ifdef Output_PORT0
  // Port Expander Library uses SPI1 module
  SPI1_Init();                           // Initialize SPI module used with PortExpander

  Expander_Init(0);                      // Initialize Port Expander

  Expander_Set_DirectionPortA(0, 0x00);  // Set Expander's PORTA to be output

  Expander_Set_DirectionPortB(0,0xFF);   // Set Expander's PORTB to be input
  Expander_Set_PullUpsPortB(0,0xFF);     // Set pull-ups to all of the Expander's PORTB pins

  while(1) {                             // Endless loop
    Expander_Write_PortA(0, i++);        // Write i to expander's PORTA
    PORTA = Expander_Read_PortA(0);      // Read expander's PORTA and write it to LEDs
    Delay_ms(100);
  }
  #endif

  #ifdef Output_PORT1
    // Port Expander Library uses SPI1 module
  SPI1_Init();                           // Initialize SPI module used with PortExpander

  Expander_Init(0);                      // Initialize Port Expander

  Expander_Set_DirectionPortB(0, 0x00);  // Set Expander's PORTB to be output

  Expander_Set_DirectionPortA(0,0xFF);   // Set Expander's PORTA to be input
  Expander_Set_PullUpsPortA(0,0xFF);     // Set pull-ups to all of the Expander's PORTB pins

  while(1) {                             // Endless loop
    Expander_Write_PortB(0, i++);        // Write i to expander's PORTB
    PORTA = Expander_Read_PortB(0);      // Read expander's PORTB and write it to LEDs
    Delay_ms(100);
  }
  #endif

}
